<?php

use Nette\Forms\Form;
use Instante\Bootstrap3Renderer\BootstrapRenderer;

$app->get('/user', function () {
    echo "create user form";
});

$app->post('/user', function () {
    echo "insert user";
});

$app->get('/user/:id', function ($id) {
    echo "view user $id";
});

$app->get('/user/:id/edit', function ($id) {
    echo "edit user $id form";
});

$app->put('/user/:id', function ($id) {
    echo "update user $id";
});

$app->delete('/user/:id', function ($id) {
    echo "delete user $id";
});

function plot_filter_form($dbuser, $matches, $default_discipline) {
    global $db;

    $disciplines = array('barebow', 'recurve', 'compound');
    $disciplines = array_combine($disciplines, array_map('ucfirst', $disciplines));

    $match_ids = array_unique($matches->fetchPairs(null, 'id'));
    $tags = $db->table('tag')
        ->select('DISTINCT name AS name')
        ->where(array('match_id' => $match_ids))
        ->fetchPairs('name', 'name');
    asort($tags);

    $distances = $matches->fetchPairs('distance', 'distance');
    asort($distances);
    $distances = map_format(_('%d meters'), $distances);

    $form = new Form;
    $form->setRenderer(new BootstrapRenderer);
    $form->setAction("user/$dbuser->id/plot");
    $form->setMethod('get');

    $form->addText('from', _('From'))
        ->setType('date')
        ->setAttribute('placeholder', _('YYYY-MM-DD'));
    $form->addText('until', _('Until'))
        ->setType('date')
        ->setAttribute('placeholder', _('YYYY-MM-DD'))
        ->setDefaultValue(strftime('%Y-%m-%d'));
    $form->addMultiSelect('tags', _('Tags'), $tags);
    $form->addSelect('distance', _('Distance'), $distances)
        ->setPrompt(_('Select a distance'));
    $form->addRadioList('discipline', _('Discipline'), $disciplines)
        ->setAttribute('data-inline', true)
        ->setDefaultValue($default_discipline);
    $form->addSubmit('send', _('Filter'));

    return $form;
}

$app->get('/user/:id/plot', function ($id) use ($app, $db, $user) {
    require_user_access($id);
    $dbuser = $db->table('user')->get($user->getId());

    $matches = $db->table('match')
        ->where(array('user_id' => $id))
        ->order('created_at DESC');

    if ($matches->count()) {
        $last_match = $matches->fetch();
        $default_discipline = $last_match->discipline;
        $matches->rewind();
    } else {
        $default_discipline = 'recurve';
    }

    $form = plot_filter_form($dbuser, $matches, $default_discipline);

    if ($form->isSubmitted()) {
        $v = $form->getValues();

        if ($v->tags) {
            $match_ids = $db->table('tag')
                ->select('match_id')
                ->where('name', $v->tags)
                ->fetchPairs(null, 'match_id');
            $matches->where('id', $match_ids);
        }

        if ($v->from && $v->until)
            $matches->where('DATE(created_at) BETWEEN ? AND ?', $v->from, $v->until);
        elseif ($v->from)
            $matches->where('DATE(created_at) >= ?', $v->from);
        elseif ($v->until)
            $matches->where('DATE(created_at) <= ?', $v->until);

        if ($v->distance)
            $matches->where('distance', $v->distance);

        if ($v->discipline)
            $matches->where('discipline', $v->discipline);
    } else {
        $matches->where('discipline', $default_discipline);
    }

    $app->render('user/plot', compact('dbuser', 'form', 'matches'));
});
