<?php

function load_config($filename, $optional=false) {
    if (!file_exists(__DIR__ . '/' . $filename)) {
        if ($optional)
            return null;
        else
            throw new RuntimeException("missing file $filename");
    }

    $config = json_decode(file_get_contents(__DIR__ . '/' . $filename), true);

    if ($config === null)
        throw new RuntimeException("file $filename is not valid JSON");

    return $config;
}

function set_accept_locale($supported_languages=null) {
    if (!isset($_SERVER['HTTP_ACCEPT_LANGUAGE']))
        return null;

    foreach (explode(',', $_SERVER['HTTP_ACCEPT_LANGUAGE']) as $locale) {
        if (!preg_match('/^(\w\w)(?:[-_](\w\w))?(\.\w+)?$/', $locale, $m))
            continue;

        $lang = $m[1];
        $region = isset($m[2]) ? '_'.$m[2] : '';
        $ext = isset($m[3]) ? $m[3] : '';

        if ($supported_languages === null || in_array($lang, $supported_languages)) {
            $locale = setlocale(LC_ALL,
                $lang.$region.$ext,
                $lang.$region.'.utf8',
                $lang.$region,
                $lang.$ext,
                $lang.'.utf8',
                $lang);
            return $locale;
        }
    }

    return null;
}

function require_user_access($user_id) {
    global $user, $app;

    if (!$user->isLoggedIn())
        $app->redirect(ROOT_URL . '/login');

    if ($user->getId() != $user_id && !in_array('admin', $user->getRoles()))
        $app->halt(403, _('No access to this user'));
}

function find_match($id) {
    global $app, $db, $user;
    $match = $db->table('match')->get($id);
    $match || $app->halt(404, _('Match does not exist'));
    require_user_access($match->user_id);
    return $match;
}

function map_format($format, $array) {
    $arr = array();

    foreach ($array as $key => $value)
        $arr[$key] = sprintf($format, $value);

    return $arr;
}

function pack_scores($scores) {
    $blob = '';
    foreach ($scores as $score)
        $blob .= pack('C', $score);
    return $blob;
}

function unpack_scores($blob) {
    return array_map(function($c) { return unpack('C', $c)[1]; }, str_split($blob));
}

function match_arrows($row) {
    return sprintf('%d &times; %d', $row->turns, $row->arrows);
}

function match_score($row) {
    return array_sum(unpack_scores($row->scores));
}

function match_avg_score($row) {
    return match_score($row) / ($row->turns * $row->arrows);
}
